@@ -76,7 +76,7 @@ def terminalfit(text: str, delta: int = 0, width: int = 0, **kw) -> str:
 
     def bulletpoint(line):
         wrapped = textwrap.wrap(line, width - 2, **kw)
-        wrapped[1:] = ['  {}'.format(l) for l in wrapped[1:]]
+        wrapped[1:] = ['  {}'.format(line) for line in wrapped[1:]]
         return '\n'.join(wrapped)
 
     def fitted(paragraphs):
@@ -108,7 +108,6 @@ def documentation(unit):
     Return the documentation string of a given unit as it should be displayed
     on the command line. Certain pdoc3-specific reference strings are removed.
     """
-    import inspect
     import re
     docs = inspect.getdoc(unit)
     docs = re.sub(R'`refinery\.(?:\w+\.)*(\w+)`', R'\1', docs)
