@@ -3,43 +3,12 @@
 import sys
 import textwrap
 
-from math import log
-
-from . import HexViewerMixin, get_terminal_size
-from .. import Unit
-
-try:
-    import numpy
-
-    def _np_entropy(data: bytearray) -> float:
-        value, counts = numpy.unique(data, return_counts=True)
-        probs = counts / len(data)
-        # 8 bits are the maximum number of bits of information in a byte
-        return 0.0 + -sum(p * log(p, 2) for p in probs) / 8.0
-
-except ImportError:
-    _np_entropy = None
+from . import arg, HexViewer, get_terminal_size
+from ...lib.types import INF
+from ...lib.tools import entropy
 
 
-def entropy(data: bytearray) -> float:
-    """
-    Computes the entropy of `data` over the alphabet of all bytes.
-    """
-    if not data:
-        return 0.0
-    if _np_entropy:
-        return _np_entropy(data)
-    else:
-        from collections import defaultdict
-        histogram = defaultdict(int)
-        for b in data:
-            histogram[b] += 1
-        p = 1. / len(data)
-        S = [histogram[b] * p for b in histogram]
-        return 0.0 + -sum(q * log(q, 2) for q in S) / 8.0
-
-
-class peek(Unit, HexViewerMixin):
+class peek(HexViewer):
     """
     The unit extracts preview information of the input data and displays it on
     the standard error stream. If the standard output of this unit is connected
@@ -47,21 +16,19 @@ class peek(Unit, HexViewerMixin):
     a terminal, the data is discarded instead.
     """
 
-    def interface(self, argp):
-        from ...lib.argformats import number
-        lines = argp.add_mutually_exclusive_group()
-        lines.add_argument('-l', '--lines', metavar='N', type=number, default=10,
-            help='Specify number N of lines in the preview, default is 10.')
-        lines.add_argument('-a', '--lines-all', action='store_const', dest='lines', const=None,
-            help='Output all possible preview lines without restriction')
-        peek = argp.add_mutually_exclusive_group()
-        peek.add_argument('-d', '--decode', action='store_true',
-            help='Attempt to decode and display printable data.')
-        peek.add_argument('-e', '--esc', action='store_true',
-            help='Always peek data as string, escape characters if necessary.')
-        peek.add_argument('-b', '--brief', action='store_true',
-            help='One line peek, implies --lines=0.')
-        return super().interface(self.hexviewer_interface(argp))
+    def __init__(
+        self,
+        lines  : arg('-l', group='SIZE', help='Specify number N of lines in the preview, default is 10.') = 10,
+        all    : arg('-a', group='SIZE', help='Output all possible preview lines without restriction') = False,
+        decode : arg('-d', group='MODE', help='Attempt to decode and display printable data.') = False,
+        esc    : arg('-e', group='MODE', help='Always peek data as string, escape characters if necessary.') = False,
+        brief  : arg('-b', group='MODE', help='One line peek, implies --lines=0.') = False,
+        hexaddr=True, expand=False, width=0
+    ):
+        lines = INF if all else lines
+        super(peek, self).__init__(
+            hexaddr=hexaddr, expand=expand, width=width, lines=lines, decode=decode, esc=esc, brief=brief)
+        self.separate = True
 
     def process(self, data):
         for line in self._peeklines(data):
@@ -70,10 +37,6 @@ class peek(Unit, HexViewerMixin):
             self.log_info('forwarding input to next unit')
             yield data
 
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-        self.separate = True
-
     def _peeklines(self, data):
         import codecs
         import string
@@ -82,7 +45,7 @@ class peek(Unit, HexViewerMixin):
         from ...lib.magic import magicparse
 
         peeks = [
-            F'{entropy(bytearray(data)) * 100:05.2f}% entropy',
+            F'{entropy(memoryview(data)) * 100:05.2f}% entropy',
             format_size(len(data), align=not self.args.lines)
         ]
 
@@ -94,6 +57,7 @@ class peek(Unit, HexViewerMixin):
         header = ', '.join(peeks)
 
         dump = None
+        termsize = get_terminal_size()
         working_codec = None
 
         if data and not self.args.brief:
@@ -112,9 +76,8 @@ class peek(Unit, HexViewerMixin):
                         self.log_info(F'data contains {ratio * 100:.2f}% printable characters, this is too low.')
                         continue
 
-                    width = self.args.width or get_terminal_size()
-                    if self.args.lines is not None:
-                        decoded = decoded[:width * self.args.lines]
+                    width = self.args.width or termsize
+                    decoded = decoded[:abs(width * self.args.lines)]
                     dump = [
                         line.rstrip('\r')
                         for chunk in textwrap.wrap(
@@ -129,22 +92,22 @@ class peek(Unit, HexViewerMixin):
                     break
 
             if not dump:
-                total = self.args.lines * get_terminal_size() // 3
+                total = abs(self.args.lines * termsize // 3)
                 dump = self.hexdump(data, total=total)
 
-            dump = list(itertools.islice(dump, 0, self.args.lines))
+            dump = list(itertools.islice(dump, 0, abs(self.args.lines)))
 
-        termsize = get_terminal_size()
+        width = max(len(d) for d in dump) if self.args.width else termsize
 
         def separator(title=None):
-            if title is None or termsize <= len(title) + 8:
-                return termsize * '-'
-            return F'--{title}' + '-' * (termsize - len(title) - 2)
+            if title is None or width <= len(title) + 8:
+                return width * '-'
+            return F'--{title}' + '-' * (width - len(title) - 2)
 
         yield separator()
 
-        if termsize:
-            yield from textwrap.wrap(header, termsize)
+        if width:
+            yield from textwrap.wrap(header, width)
         else:
             yield header
 
